"""
Created on 26 mars 2018

@author: Stephane Tonneau

"""

import logging
from pidclient.base_utils import LoggingMethod


class ConsoleLogging(LoggingMethod):
    """Class that encapsulates console logging methods in order to log information
    in the 'info' level.
    """

    def __init__(self, **parameters):
        """Initialisator of the class

        :param configuration: the general logging configuration
        :type configuration: a python configuration object
        """
        super(ConsoleLogging, self).__init__(**parameters)
        self.file_position = 0
        self.log_console = logging.getLogger('ConsoleLogging')
        if not self.log_console.handlers:
            self.log_console.setLevel(logging.INFO)
            hdlr = logging.StreamHandler()
            self.log_console.addHandler(hdlr)

    def close(self):
        """Close the logging instance"""
        pass

    def process_log(self, entry, meta_information):
        """Method to print a dictionary representation of both the object and
        its metadata on the console

        :param entry: the basic information
        :type entry: PidEntry
        :param meta_information: metadata on the information
        :type meta_information: Metainformation
        """
        doc = entry.to_dict()
        self.log_console.info("PID document " + meta_information.uid + "_" +
                              str(self.file_position) + " : " + str(doc))
        self.file_position += 1
